## Auto Regression 
#### Created by Ketan Gangal and Rohan Bagulwar.

This Library is created for making life of a data scientist easy. 
Currently, it is created only for regression but in future updates classification will be added.

```python
print('hello')
```